@@ -29,12 +29,13 @@ class InvalidData(StrMixin, BaseException):
 ReadError = DBError | InvalidData | InexistentItem
 
 T = TypeVar('T')
+U = TypeVar('U')
 
 class KV(ABC, Generic[T]):
   """Async, exception-free key-value store ABC"""
   
   @staticmethod
-  def of(conn_str: str, type: type[T] | None = None) -> 'KV[T]':
+  def of(conn_str: str, type: type[U] | None = None) -> 'KV[U]':
     """Create a KV from a connection string. Supports:
     - `file://<path>`: `FilesystemKV`
     - `sql+<protocol>://<conn_str>;Table=<table>`: `SQLKV`
